==> stonage-0.0.1.tar.gz: stonage-0.0.1/src/square.h <==


#ifndef __SQUARE_H
#define __SQUARE_H


enum
{
  CAN_MOVE_TO_NORTH = (1<<0),
  CAN_MOVE_TO_SOUTH = (1<<1),
  CAN_MOVE_TO_EAST  = (1<<2),
  CAN_MOVE_TO_WEST  = (1<<3),
  AFTER_MOVE_CRASH  = (1<<4),
  START             = (1<<5),
  FINISH            = (1<<6),
  CAN_GO_ABOVE      = (1<<7),
  KEY_RED	    = (1<<8),
  KEY_BLUE	    = (1<<9),
  KEY_GREEN	    = (1<<10),
  NEED_KEY_RED      = (1<<11),
  NEED_KEY_BLUE     = (1<<12),
  NEED_KEY_GREEN    = (1<<13)
};

#define CAN_MOVE_TO_MASK (CAN_MOVE_TO_NORTH|CAN_MOVE_TO_SOUTH|CAN_MOVE_TO_EAST|CAN_MOVE_TO_WEST)


struct square_desc
{
  unsigned char properties[4] __attribute__ ((packed)); /* properties of the square  (u32) */
  unsigned char nimages[2]    __attribute__ ((packed)); /* number of images for animation (u16) */
  unsigned char delay[2]      __attribute__ ((packed)); /* delay between 2 images in ms */
  unsigned char filenamesz[2] __attribute__ ((packed)); /* Size of the block of filename */
};

struct 
{
  char *text;
  unsigned int flags;
} static square_properties_text2enum[] =
{
   {"CAN_MOVE_TO_NORTH", CAN_MOVE_TO_NORTH},
   {"CAN_MOVE_TO_SOUTH", CAN_MOVE_TO_SOUTH},
   {"CAN_MOVE_TO_EAST", CAN_MOVE_TO_EAST},
   {"CAN_MOVE_TO_WEST", CAN_MOVE_TO_WEST},
   {"AFTER_MOVE_CRASH", AFTER_MOVE_CRASH},
   {"START", START},
   {"FINISH", FINISH},
   {"CAN_GO_ABOVE", CAN_GO_ABOVE},
   {"KEY_RED", KEY_RED},	
   {"KEY_BLUE", KEY_BLUE},	
   {"KEY_GREEN", KEY_GREEN},	
   {"NEED_KEY_RED", NEED_KEY_RED},
   {"NEED_KEY_BLUE", NEED_KEY_BLUE},
   {"NEED_KEY_GREEN", NEED_KEY_GREEN},
   {0,0 }
};

#ifndef _NO_GFX_

#include <SDL.h>

struct t_square
{
  unsigned int properties;
  int nimages;
  int delay;
  SDL_Surface **images;
};


SDL_Surface *Square_Load(char *filename);
void Square_Free(struct t_square *s);
#endif

#endif

==> stonage-0.0.2.tar.gz: stonage-0.0.2/src/square.h <==


#ifndef __SQUARE_H
#define __SQUARE_H


enum
{
  CAN_MOVE_TO_NORTH = (1<<0),
  CAN_MOVE_TO_SOUTH = (1<<1),
  CAN_MOVE_TO_EAST  = (1<<2),
  CAN_MOVE_TO_WEST  = (1<<3),
  AFTER_MOVE_CRASH  = (1<<4),
  START             = (1<<5),
  FINISH            = (1<<6),
  CAN_GO_ABOVE      = (1<<7),
  KEY_RED	    = (1<<8),
  KEY_BLUE	    = (1<<9),
  KEY_GREEN	    = (1<<10),
  NEED_KEY_RED      = (1<<11),
  NEED_KEY_BLUE     = (1<<12),
  NEED_KEY_GREEN    = (1<<13),
  HOURGLASS         = (1<<14),
  TELEPORT1         = (1<<15),
  TELEPORT2         = (1<<16),
  TELEPORT3         = (1<<17)
};

#define CAN_MOVE_TO_MASK (CAN_MOVE_TO_NORTH|CAN_MOVE_TO_SOUTH|CAN_MOVE_TO_EAST|CAN_MOVE_TO_WEST)


struct square_desc
{
  unsigned char properties[4] __attribute__ ((packed)); /* properties of the square  (u32) */
  unsigned char nimages[2]    __attribute__ ((packed)); /* number of images for animation (u16) */
  unsigned char delay[2]      __attribute__ ((packed)); /* delay between 2 images in ms */
  unsigned char filenamesz[2] __attribute__ ((packed)); /* Size of the block of filename */
};

struct 
{
  char *text;
  unsigned int flags;
} static square_properties_text2enum[] =
{
   {"CAN_MOVE_TO_NORTH", CAN_MOVE_TO_NORTH},
   {"CAN_MOVE_TO_SOUTH", CAN_MOVE_TO_SOUTH},
   {"CAN_MOVE_TO_EAST", CAN_MOVE_TO_EAST},
   {"CAN_MOVE_TO_WEST", CAN_MOVE_TO_WEST},
   {"AFTER_MOVE_CRASH", AFTER_MOVE_CRASH},
   {"START", START},
   {"FINISH", FINISH},
   {"CAN_GO_ABOVE", CAN_GO_ABOVE},
   {"KEY_RED", KEY_RED},	
   {"KEY_BLUE", KEY_BLUE},	
   {"KEY_GREEN", KEY_GREEN},	
   {"NEED_KEY_RED", NEED_KEY_RED},
   {"NEED_KEY_BLUE", NEED_KEY_BLUE},
   {"NEED_KEY_GREEN", NEED_KEY_GREEN},
   {"HOURGLASS", HOURGLASS},
   {"TELEPORT1", TELEPORT1},
   {"TELEPORT2", TELEPORT2},
   {"TELEPORT3", TELEPORT3},
   {0,0 }
};

#ifndef _NO_GFX_

#include <SDL.h>

struct t_square
{
  unsigned int properties;
  int nimages;
  int delay;
  SDL_Surface **images;
};


SDL_Surface *Square_Load(char *filename);
void Square_Free(struct t_square *s);
#endif

#endif
